@@ -18,6 +18,7 @@
 #include "cccs.h"
 #include "extsimkernels/spicecompat.h"
 #include "extsimkernels/verilogawriter.h"
+#include "node.h"
 
 
 CCCS::CCCS()
@@ -58,9 +59,13 @@ CCCS::CCCS()
   Name  = "SRC";
   SpiceModel = "F";
 
-  Props.append(new Property("G", "1", true,
-		QObject::tr("forward transfer factor")));
-  Props.append(new Property("T", "0", false, QObject::tr("delay time (Qucsator only)")));
+  Property::Builder b;
+
+  Props.append(b.visible().simulator(spicecompat::simAll)
+    .property("G", "1", QObject::tr("forward transfer factor")));
+
+  Props.append(b.hidden().simulator(spicecompat::simQucsator)
+    .property("T", "0", QObject::tr("delay time (Qucsator only)")));
 }
 
 CCCS::~CCCS()
