@@ -18,17 +18,17 @@
 #ifndef HB_SIM_H
 #define HB_SIM_H
 
-#include "component.h"
+#include "simulation.h"
 
 
-class HB_Sim : public Component  {
+class HB_Sim : public qucs::component::SimulationComponent  {
 public:
   HB_Sim();
   ~HB_Sim();
   Component* newOne();
   static Element* info(QString&, char* &, bool getNewOne=false);
 protected:
-  QString spice_netlist(bool isXyce);
+  QString spice_netlist(spicecompat::SpiceDialect dialect = spicecompat::SPICEDefault);
 };
 
 #endif
