@@ -351,10 +351,13 @@ int Diagram::regionCode(float x, float y) const {
 // ------------------------------------------------------------
 // Is virtual. This one is for round diagrams only.
 bool Diagram::insideDiagram(float x, float y) const {
-    float R = float(x2) / 2.0 + 1.0; // +1 seems better (graph sometimes little outside)
-    x -= R;
-    y -= R;
-    return ((x * x + y * y) <= R * R);
+  float tol = 0.5;  // Tolerance. Otherwise, it may discard points close to the circular plot border
+  float R = float(x2) / 2.0 + 1.0; // +1 seems better (graph sometimes little outside)
+  x -= R;
+  y -= R;
+
+  float rTol = R + tol; // Radius plus tolerance
+  return ((x * x + y * y) <= rTol * rTol);
 }
 
 /*!
@@ -652,7 +655,7 @@ void Diagram::getAxisLimits(Graph *pg) {
     int z;
     double x, y, *p;
     DataX const *pD = pg->axis(0);
-    if (pD == 0) return;
+    if (pD == nullptr) return;
 
     if (Name[0] != 'C') {   // not for location curves
         p = pD->Points;
@@ -684,7 +687,7 @@ void Diagram::getAxisLimits(Graph *pg) {
     else pa = &zAxis;
     (pa->numGraphs)++;    // count graphs
     p = pg->cPointsY;
-    if (p == 0) return;    // if no data => invalid
+    if (p == nullptr) return;    // if no data => invalid
     for (z = pg->countY * pD->count; z > 0; z--) {  // check every y coordinate
         x = *(p++);
         y = *(p++);
@@ -796,7 +799,7 @@ void Diagram::updateGraphData() {
             calcData(pg);   // calculate screen coordinates
         else if (pg->cPointsY) {
             delete[] pg->cPointsY;
-            pg->cPointsY = 0;
+            pg->cPointsY = nullptr;
         }
     }
 
@@ -999,7 +1002,7 @@ int Graph::loadDatFile(const QString &fileName) {
     if (Variable.right(3) != ".X ") { // not "digital"
 
         for (int z = counting; z > 0; z--) {
-            pEnd = 0;
+            pEnd = nullptr;
             while ((*pPos) && (*pPos <= ' ')) pPos++; // find start of next number
             x = strtod(pPos, &pEnd);  // real part
             pPos = pEnd + 1;
@@ -1008,11 +1011,11 @@ int Graph::loadDatFile(const QString &fileName) {
             else {
                 if (((*pEnd != '+') && (*pEnd != '-')) || (*pPos != 'j')) {
                     delete[] g->cPointsY;
-                    g->cPointsY = 0;
+                    g->cPointsY = nullptr;
                     return 0;
                 }
                 *pPos = *pEnd;  // overwrite 'j' with sign
-                pEnd = 0;
+                pEnd = nullptr;
                 y = strtod(pPos, &pEnd); // imaginary part
                 *pPos = 'j';   // write back old character
                 pPos = pEnd;
@@ -1055,7 +1058,7 @@ int Graph::loadDatFile(const QString &fileName) {
             while ((*pPos) && (*pPos <= ' ')) pPos++; // find start of next bit vector
             if (*pPos == 0) {
                 delete[] g->cPointsY;
-                g->cPointsY = 0;
+                g->cPointsY = nullptr;
                 return 0;
             }
 
@@ -1153,7 +1156,7 @@ int Graph::loadIndepVarData(const QString &Variable,
 
         if (pPos == pEnd) {
             delete[] pD->Points;
-            pD->Points = 0;
+            pD->Points = nullptr;
             return -1;
         }
 
@@ -1207,23 +1210,6 @@ int Diagram::checkColumnWidth(const QString &Str,
     return colWidth;
 }
 
-// ------------------------------------------------------------
-void Diagram::setCenter(int x, int y, bool relative) {
-    if (relative) {
-        cx += x;
-        cy += y;
-    } else {
-        cx = x;
-        cy = y;
-    }
-}
-
-// -------------------------------------------------------
-void Diagram::getCenter(int &x, int &y) {
-    x = cx + (x2 >> 1);
-    y = cy - (y2 >> 1);
-}
-
 // ------------------------------------------------------------
 Diagram *Diagram::newOne() {
     return new Diagram();
@@ -2003,6 +1989,18 @@ void Diagram::calcCoordinateP(const double *x, const double *y, const double *z,
 };
 
 
+QRect Diagram::boundingRect() const noexcept
+{
+    // Despite of having "Bounding_" in the name these are apparently
+    // not boungings at all. Computations are taken "as is" from legacy
+    // implementation, they work though it's hard to tell how.
+    int x1_ = cx - Bounding_x1;
+    int y1_ = cy - y2 - Bounding_y2;
+    int x2_ = cx + x2 + Bounding_x2;
+    int y2_ = cy - Bounding_y1;
+    return QRect{QPoint{x1_, y1_}, QPoint{x2_, y2_}}.normalized();
+}
+
 //void Diagram::SetLimitsBySelectionRect(QRectF) {}
 
 
