@@ -17,7 +17,6 @@
 
 
 #include "ngspice.h"
-#include "xspice_cmbuilder.h"
 #include "components/iprobe.h"
 #include "components/vprobe.h"
 #include "components/equation.h"
@@ -28,10 +27,18 @@
 #include "main.h"
 #include "misc.h"
 #include "qucs.h"
+#include "settings.h"
+#include "node.h"
+#include "wire.h"
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#include <QScopedPointer>
+
+#include <iostream>
+
 /*!
   \file ngspice.cpp
   \brief Implementation of the Ngspice class
@@ -39,22 +46,23 @@
 
 /*!
  * \brief Ngspice::Ngspice Class constructor
- * \param sch_ Schematic that need to be simulated with Ngspice.
+ * \param schematic Schematic that need to be simulated with Ngspice.
  * \param parent Parent object
  */
-Ngspice::Ngspice(Schematic *sch_, QObject *parent) :
-    AbstractSpiceKernel(sch_, parent)
+Ngspice::Ngspice(Schematic* schematic, QObject *parent) :
+    AbstractSpiceKernel(schematic, parent),
+    a_spinit_name()
 {
     if (QFileInfo(QucsSettings.NgspiceExecutable).isRelative()) { // this check is related to MacOS
-        simulator_cmd = QFileInfo(QucsSettings.BinDir + QucsSettings.NgspiceExecutable).absoluteFilePath();
+        a_simulator_cmd = QFileInfo(QucsSettings.BinDir + QucsSettings.NgspiceExecutable).absoluteFilePath();
     } else {
-        simulator_cmd = QFileInfo(QucsSettings.NgspiceExecutable).absoluteFilePath();
+        a_simulator_cmd = QFileInfo(QucsSettings.NgspiceExecutable).absoluteFilePath();
     }
-    if (!QFileInfo::exists(simulator_cmd)) {
-        simulator_cmd = QucsSettings.NgspiceExecutable; //rely on $PATH
+    if (!QFileInfo::exists(a_simulator_cmd)) {
+        a_simulator_cmd = QucsSettings.NgspiceExecutable; //rely on $PATH
     }
-    simulator_parameters = "";
-    spinit_name = QDir::toNativeSeparators(QucsSettings.S4Qworkdir+"/.spiceinit");
+    a_simulator_parameters = "";
+    a_spinit_name = QDir::toNativeSeparators(QucsSettings.S4Qworkdir+"/.spiceinit");
 }
 
 /*!
@@ -65,23 +73,28 @@ Ngspice::Ngspice(Schematic *sch_, QObject *parent) :
  * \param[out] vars The list of output variables and node names.
  * \param[out] outputs The list of spice output raw text files.
  */
-void Ngspice::createNetlist(QTextStream &stream, int ,
-                       QStringList &simulations, QStringList &vars, QStringList &outputs)
+void Ngspice::createNetlist(
+        QTextStream& stream,
+        QStringList& simulations,
+        QStringList& vars,
+        QStringList& outputs)
 {
     Q_UNUSED(simulations);
 
-    if(!prepareSpiceNetlist(stream)) return; // Unable to perform spice simulation
+    stream << "* Qucs " << PACKAGE_VERSION << "  " << a_schematic->getDocName() << "\n";
 
     // include math. functions for inter-simulator compat.
     QString mathf_inc;
     bool found = findMathFuncInc(mathf_inc);
     // Let to simulate schematic without mathfunc.inc file
     if (found && QucsSettings.DefaultSimulator != spicecompat::simSpiceOpus)
-        stream<<QString(".INCLUDE \"%1\"\n").arg(mathf_inc);
+        stream<<QStringLiteral(".INCLUDE \"%1\"\n").arg(mathf_inc);
 
+    stream<<collectSpiceLibs(a_schematic); // collect libraries on the top of netlist
+    if(!prepareSpiceNetlist(stream)) return; // Unable to perform spice simulation
     startNetlist(stream); // output .PARAM and components
 
-    if (DC_OP_only) {
+    if (a_DC_OP_only) {
         stream<<".control\n"  // Execute only DC OP analysis
               <<"set filetype=ascii\n" // Ignore all other simulations
               <<"op\n"
@@ -97,21 +110,22 @@ void Ngspice::createNetlist(QTextStream &stream, int ,
 
     // set variable names for named nodes and wires
     vars.clear();
-    for(Node *pn = Sch->DocNodes.first(); pn != 0; pn = Sch->DocNodes.next()) {
-      if(pn->Label != 0) {
-          if (!vars.contains(pn->Label->Name)) {
-              vars.append(pn->Label->Name);
+    for(Node *pn : a_schematic->a_DocNodes) {
+      if(pn->hasLabel()) {
+          if (!vars.contains(pn->label()->Name)) {
+            vars.append(pn->label()->Name);
           }
       }
     }
-    for(Wire *pw = Sch->DocWires.first(); pw != 0; pw = Sch->DocWires.next()) {
-      if(pw->Label != 0) {
-          if (!vars.contains(pw->Label->Name)) {
-              vars.append(pw->Label->Name);
+    for(Wire *pw : a_schematic->a_DocWires) {
+      if(pw->hasLabel()) {
+          if (!vars.contains(pw->label()->Name)) {
+              vars.append(pw->label()->Name);
           }
       }
     }
-    for(Component *pc = Sch->DocComps.first(); pc != 0; pc = Sch->DocComps.next()) {
+
+    for(Component *pc : a_schematic->a_DocComps) {
         if (pc->isProbe) {
             QString var_pr = pc->getProbeVariable();
             if (!vars.contains(var_pr)) {
@@ -132,7 +146,7 @@ void Ngspice::createNetlist(QTextStream &stream, int ,
             for(const auto &file : osdi_files) {
                 QString abs_file = QucsSettings.QucsWorkDir.absolutePath() +
                         QDir::separator() + file;
-                stream<<QString("pre_osdi '%1'\n").arg(abs_file);
+                stream<<QStringLiteral("pre_osdi '%1'\n").arg(abs_file);
             }
         }
     }
@@ -145,8 +159,7 @@ void Ngspice::createNetlist(QTextStream &stream, int ,
     unsigned int pzSims = 0;
 
     outputs.clear();
-    for ( unsigned int i = 0 ; i < Sch->DocComps.count() ; i++ ) {
-        Component *pc = Sch->DocComps.at(i);
+    for (Component* pc : a_schematic->a_DocComps) {
         if ( !pc->isSimulation ) continue;
         if ( pc->isActive != COMP_IS_ACTIVE ) continue;
 
@@ -159,8 +172,7 @@ void Ngspice::createNetlist(QTextStream &stream, int ,
         QString cnt_var;
 
         // Duplicate .PARAM in .control section. They may be used in euqations
-        for ( unsigned int i = 0 ; i < Sch->DocComps.count() ; i++ ) {
-            Component *pc1 = Sch->DocComps.at(i);
+        for (Component* pc1 : a_schematic->a_DocComps) {
             if ( pc1->isActive != COMP_IS_ACTIVE ) continue;
             if ( pc1->Model == "Eqn" ) {
                 spiceNetlist.append((reinterpret_cast<Equation *>(pc1))->getNgspiceScript());
@@ -170,13 +182,12 @@ void Ngspice::createNetlist(QTextStream &stream, int ,
         QString nods;
         for (const QString& nod : vars) {
             if ( nod.endsWith("#branch") )
-                nods.append(QString("i(%1) ").arg(nod.section('#', 0, 0)));
+                nods.append(QStringLiteral("i(%1) ").arg(nod.section('#', 0, 0)));
             else
-                nods.append(QString("v(%1) ").arg(nod));
+                nods.append(QStringLiteral("v(%1) ").arg(nod));
         }
 
-        for ( unsigned int i = 0 ; i < Sch->DocComps.count() ; i++ ) {
-            Component *pc1 = Sch->DocComps.at(i);
+        for (Component* pc1 : a_schematic->a_DocComps) {
             if ( !pc1->isSimulation ) continue;
             if ( pc1->isActive != COMP_IS_ACTIVE ) continue;
             QString sim_typ = pc1->Model;
@@ -199,8 +210,7 @@ void Ngspice::createNetlist(QTextStream &stream, int ,
         } else if ( sim_typ == ".TR" ) {
             timeSims++;
             spiceNetlist.append(pc->getSpiceNetlist());
-            for ( unsigned int i = 0 ; i < Sch->DocComps.count() ; i++ ) {
-                Component *pc1 = Sch->DocComps.at(i);
+            for (Component* pc1 : a_schematic->a_DocComps) {
                 if ( !pc1->isSimulation ) continue;
                 if ( pc1->isActive != COMP_IS_ACTIVE ) continue;
                 if ( pc1->Model == ".FOURIER" ) {
@@ -217,7 +227,7 @@ void Ngspice::createNetlist(QTextStream &stream, int ,
             spiceNetlist.append(pc->getSpiceNetlist());
             nods = pc->Props.at(1)->Value;
             nods.replace(';', ' ');
-            outputs.append(pc->Props.at(2)->Value.split(';', qucs::SkipEmptyParts));
+            outputs.append(pc->Props.at(2)->Value.split(';', Qt::SkipEmptyParts));
 
             QRegularExpression ac_rx("^\\s*ac\\s.*", QRegularExpression::CaseInsensitiveOption);
             QRegularExpression sp_rx("^\\s*sp\\s.*", QRegularExpression::CaseInsensitiveOption);
@@ -257,12 +267,12 @@ void Ngspice::createNetlist(QTextStream &stream, int ,
             outputs.append("spice4qucs." + sim_name + ".cir.noise");
             if ( hasParSWP ) {  // Set necessary plot number to output Noise spectrum
                 // each step of parameter sweep creates new couple of noise plots
-                spiceNetlist.append(QString("let noise_%1 = 2*%1+1\n").arg(cnt_var));
-                spiceNetlist.append(QString("setplot noise$&noise_%1\n").arg(cnt_var));
+                spiceNetlist.append(QStringLiteral("let noise_%1 = 2*%1+1\n").arg(cnt_var));
+                spiceNetlist.append(QStringLiteral("setplot noise$&noise_%1\n").arg(cnt_var));
             } else {  // Set Noise1 plot to output noise spectrum
                 spiceNetlist.append("setplot noise1\n");
             }
-            nods = "inoise_spectrum onoise_spectrum";
+            nods = "noise1.all";
         } else if ( sim_typ == ".PZ" ) {
             pzSims++;
             spiceNetlist.append(pc->getSpiceNetlist());
@@ -286,8 +296,8 @@ void Ngspice::createNetlist(QTextStream &stream, int ,
         } else if ( sim_typ == ".FFT" ) {
             freqSims++;
             spiceNetlist.append(pc->getSpiceNetlist());
-            spiceNetlist.append(QString("linearize %1\n").arg(nods));
-            spiceNetlist.append(QString("fft %1\n").arg(nods));
+            spiceNetlist.append(QStringLiteral("linearize %1\n").arg(nods));
+            spiceNetlist.append(QStringLiteral("fft %1\n").arg(nods));
         } else if ( sim_typ == ".DC" ) {
             dcSims++;
             spiceNetlist.append(pc->getSpiceNetlist());
@@ -303,8 +313,7 @@ void Ngspice::createNetlist(QTextStream &stream, int ,
 
         if ( (sim_typ != ".PZ") && (sim_typ != ".SENS") && (sim_typ != ".SENS_AC") ) {
             QStringList dep_vars;
-            for ( unsigned int i = 0 ; i < Sch->DocComps.count() ; i++ ) {
-                Component *pc1 = Sch->DocComps.at(i);
+            for (Component* pc1 : a_schematic->a_DocComps) {
                 if ( pc1->isActive != COMP_IS_ACTIVE ) continue;
                 if ( pc1->Model == "Eqn" || pc1->Model == "NutmegEq" )
                     spiceNetlist.append(pc1->getEquations(sim_name, dep_vars));
@@ -314,27 +323,43 @@ void Ngspice::createNetlist(QTextStream &stream, int ,
 
         if ( sim_typ == ".DC" ) {
             QString out = "spice4qucs." + sim_name + ".ngspice.dc.print";
-            spiceNetlist.append(QString("print %1 > %2\n").arg(nods).arg(out));
+            spiceNetlist.append(QStringLiteral("print %1 > %2\n").arg(nods).arg(out));
             outputs.append(out);
-        } else if ( (sim_typ != ".PZ") && (sim_typ != ".SENS") && (sim_typ != ".SENS_AC") ) {
+        } 
+        else if (sim_typ == ".NOISE") {
             nods = nods.simplified();
             if ( !nods.isEmpty() ) {
                 QString basenam = "spice4qucs";
                 QString filename;
                 if ( hasParSWP && hasDblSWP )
-                    filename = QString("%1.%2._swp_swp.plot").arg(basenam).arg(sim_name);
+                    filename = QStringLiteral("%1.%2._swp_swp.raw").arg(basenam).arg(sim_name);
                 else if ( hasParSWP )
-                    filename = QString("%1.%2._swp.plot").arg(basenam).arg(sim_name);
+                    filename = QStringLiteral("%1.%2._swp.raw").arg(basenam).arg(sim_name);
                 else
-                    filename = QString("%1.%2.plot").arg(basenam).arg(sim_name);
+                    filename = QStringLiteral("%1.%2.raw").arg(basenam).arg(sim_name);
                 filename.replace(' ', '_'); // Ngspice cannot understand spaces in filename
-                spiceNetlist.append(QString("write %1 %2\n").arg(filename).arg(nods));
+                spiceNetlist.append(QStringLiteral("write %1 %2\n").arg(filename).arg(nods));
+                outputs.append(filename);
+            }
+        }
+        else if ( (sim_typ != ".PZ") && (sim_typ != ".SENS") && (sim_typ != ".SENS_AC") ) {
+            nods = nods.simplified();
+            if ( !nods.isEmpty() ) {
+                QString basenam = "spice4qucs";
+                QString filename;
+                if ( hasParSWP && hasDblSWP )
+                    filename = QStringLiteral("%1.%2._swp_swp.plot").arg(basenam).arg(sim_name);
+                else if ( hasParSWP )
+                    filename = QStringLiteral("%1.%2._swp.plot").arg(basenam).arg(sim_name);
+                else
+                    filename = QStringLiteral("%1.%2.plot").arg(basenam).arg(sim_name);
+                filename.replace(' ', '_'); // Ngspice cannot understand spaces in filename
+                spiceNetlist.append(QStringLiteral("write %1 %2\n").arg(filename).arg(nods));
                 outputs.append(filename);
             }
         }
 
-        for ( unsigned int i = 0 ; i < Sch->DocComps.count() ; i++ ) {
-            Component *pc1 = Sch->DocComps.at(i);
+        for (Component* pc1 : a_schematic->a_DocComps) {
             if ( !pc1->isSimulation ) continue;
             if ( pc1->isActive != COMP_IS_ACTIVE ) continue;
             QString sim_typ = pc1->Model;
@@ -358,7 +383,7 @@ void Ngspice::createNetlist(QTextStream &stream, int ,
            << ".endc\n";
     stream << ".END\n";
 
-    needsPrefix = ( (dcSims | freqSims | timeSims | fourSims | pzSims) > 1 );
+    a_needsPrefix = a_needsPrefix || ( (dcSims | freqSims | timeSims | fourSims | pzSims) > 1 );
 
     qDebug() << '\n'
              << "Simulations:\n"
@@ -381,8 +406,7 @@ QString Ngspice::getParentSWPscript(Component *pc_swp, QString sim, bool before,
 {
     hasDblSwp = false;
     QString swp = pc_swp->Name.toLower();
-    for ( unsigned int i = 0 ; i < Sch->DocComps.count() ; i++ ) {
-        Component *pc = Sch->DocComps.at(i);
+    for (Component* pc : a_schematic->a_DocComps) {
         if ( !pc->isSimulation ) continue;
         if ( pc->isActive != COMP_IS_ACTIVE ) continue;
         if ( pc->Model == ".SW" ) {
@@ -397,7 +421,7 @@ QString Ngspice::getParentSWPscript(Component *pc_swp, QString sim, bool before,
             }
         }
     }
-    return QString("");
+    return QString();
 }
 
 /*!
@@ -406,80 +430,84 @@ QString Ngspice::getParentSWPscript(Component *pc_swp, QString sim, bool before,
  */
 void Ngspice::slotSimulate()
 {
-    output.clear();
+    a_output.clear();
 
     QString mathf_inc; // drain
     if (!findMathFuncInc(mathf_inc)) {
-        output.append("[Warning!] " + mathf_inc + " file not found!\n");
+        a_output.append("[Warning!] " + mathf_inc + " file not found!\n");
     }
 
     bool checker_error = false;
     QStringList incompat;
     if (!checkSchematic(incompat)) {
         QString s = incompat.join("; ");
-        output.append("There were SPICE-incompatible components. Simulator cannot proceed.");
-        output.append("Incompatible components are: " + s + "\n");
+        a_output.append("There were SPICE-incompatible components. Simulator cannot proceed.");
+        a_output.append("Incompatible components are: " + s + "\n");
         checker_error = true;
     }
 
     if (!checkGround()) {
-        output.append("No Ground found. Please add at least one ground!\n");
+        a_output.append("No Ground found. Please add at least one ground!\n"
+                      "Press Insert->Ground in the main menu and connect ground to one "
+                      "of the schematic nodes.\n");
         checker_error = true;
     }
 
     if (!checkSimulations()) {
-        output.append("No simulation found. Please add at least one simulation!\n");
+        a_output.append("No simulation found. Please add at least one simulation!\n"
+                      "Navigate to the \"simulations\" group in the components panel (left)"
+                      " and drag simulation to the schematic sheet. Then define its parameters.\n");
         checker_error = true;
     }
 
     if (!checkDCSimulation()) {
-        output.append("Only DC simulation found in the schematic. It has no effect!"
+        a_output.append("Only DC simulation found in the schematic. It has no effect!"
                       " Add TRAN, AC, or Sweep simulation to proceed.\n");
         checker_error = true;
     }
 
     if (!checkNodeNames(incompat)) {
         QString s = incompat.join("; ");
-        output.append("There were Nutmeg-incompatible node names. Simulator cannot proceed.\n");
-        output.append("Incompatible node names are: " + s + "\n");
+        a_output.append("There were Nutmeg-incompatible node names. Simulator cannot proceed.\n");
+        a_output.append("Incompatible node names are: " + s + "\n");
         checker_error = true;
     }
 
     if (checker_error) {
-        if (console != nullptr)
-            console->insertPlainText(output);
+        if (a_console != nullptr)
+            a_console->insertPlainText(a_output);
         //emit finished();
         emit errors(QProcess::FailedToStart);
         return;
     }
 
     QString netfile = "spice4qucs.cir";
-    QString tmp_path = QDir::toNativeSeparators(workdir+QDir::separator()+netfile);
-    SaveNetlist(tmp_path);
+    QString tmp_path = QDir::toNativeSeparators(a_workdir+QDir::separator()+netfile);
+    SaveNetlist(tmp_path, false);
 
     removeAllSimulatorOutputs();
 
-    /*XSPICE_CMbuilder *CMbuilder = new XSPICE_CMbuilder(Sch);
+    /*XSPICE_CMbuilder *CMbuilder = new XSPICE_CMbuilder(a_schematic);
     CMbuilder->cleanSpiceinit();
-    CMbuilder->createSpiceinit(collectSpiceinit(Sch));
+    CMbuilder->createSpiceinit(collectSpiceinit(a_schematic));
     if (CMbuilder->needCompile()) {
         CMbuilder->cleanCModelTree();
-        CMbuilder->createCModelTree(output);
-        CMbuilder->compileCMlib(output);
+        CMbuilder->createCModelTree(a_output);
+        CMbuilder->compileCMlib(a_output);
     }
     delete CMbuilder;*/
     cleanSpiceinit();
-    createSpiceinit(/*initial_spiceinit=*/collectSpiceinit(Sch));
+    createSpiceinit(/*initial_spiceinit=*/collectSpiceinit(a_schematic));
 
     //startNgSpice(tmp_path);
-    SimProcess->setWorkingDirectory(workdir);
-    qDebug()<<workdir;
-    QString cmd = QString("\"%1\" %2 %3").arg(simulator_cmd,simulator_parameters,netfile);
+    a_simProcess->setWorkingDirectory(a_workdir);
+    qDebug()<<a_workdir;
+    QString cmd = QStringLiteral("\"%1\" %2 %3").arg(a_simulator_cmd,a_simulator_parameters,netfile);
     QStringList cmd_args = misc::parseCmdArgs(cmd);
     QString ngsp_cmd = cmd_args.at(0);
     cmd_args.removeAt(0);
-    SimProcess->start(ngsp_cmd,cmd_args);
-    if (QucsMain)
+    a_simProcess->start(ngsp_cmd,cmd_args);
+    if (QucsMain != nullptr)
     emit started();
 }
 
@@ -491,18 +519,18 @@ void Ngspice::slotSimulate()
 bool Ngspice::checkNodeNames(QStringList &incompat)
 {
     bool result = true;
-    for(Node *pn = Sch->DocNodes.first(); pn != 0; pn = Sch->DocNodes.next()) {
-      if(pn->Label != 0) {
-          if (!spicecompat::check_nodename(pn->Label->Name)) {
-              incompat.append(pn->Label->Name);
+    for(Node *pn : a_schematic->a_DocNodes) {
+      if(pn->hasLabel()) {
+          if (!spicecompat::check_nodename(pn->label()->Name)) {
+              incompat.append(pn->label()->Name);
               result = false;
           }
       }
     }
-    for(Wire *pw = Sch->DocWires.first(); pw != 0; pw = Sch->DocWires.next()) {
-      if(pw->Label != 0) {
-          if (!spicecompat::check_nodename(pw->Label->Name)) {
-              incompat.append(pw->Label->Name);
+    for(Wire *pw : a_schematic->a_DocWires) {
+      if(pw->hasLabel()) {
+          if (!spicecompat::check_nodename(pw->label()->Name)) {
+              incompat.append(pw->label()->Name);
               result = false;
           }
       }
@@ -518,7 +546,7 @@ bool Ngspice::checkNodeNames(QStringList &incompat)
 QString Ngspice::collectSpiceinit(Schematic* sch)
 {
     QStringList collected_spiceinit;
-    for(Component *pc = sch->DocComps.first(); pc != 0; pc = sch->DocComps.next()) {
+    for(Component *pc : sch->a_DocComps) {
         if (pc->Model == "SPICEINIT") {
             collected_spiceinit += ((SpiceSpiceinit*)pc)->getSpiceinit();
         } else if (pc->Model == "Sub") {
@@ -530,7 +558,7 @@ QString Ngspice::collectSpiceinit(Schematic* sch)
             }
             collected_spiceinit += collectSpiceinit(sub);
             delete sub;
-	}
+        }
     }
     return collected_spiceinit.join("");
 }
@@ -546,7 +574,7 @@ bool Ngspice::findMathFuncInc(QString &mathf_inc)
 {
     QDir qucs_root(QucsSettings.BinDir);
     qucs_root.cdUp();
-    mathf_inc = QString("%1/share/" QUCS_NAME "/xspice_cmlib/include/ngspice_mathfunc.inc")
+    mathf_inc = QStringLiteral("%1/share/" QUCS_NAME "/xspice_cmlib/include/ngspice_mathfunc.inc")
             .arg(qucs_root.absolutePath());
     return QFile::exists(mathf_inc);
 }
@@ -557,16 +585,16 @@ bool Ngspice::findMathFuncInc(QString &mathf_inc)
  */
 void Ngspice::slotProcessOutput()
 {
-    QString s = SimProcess->readAllStandardOutput();
+    QString s = a_simProcess->readAllStandardOutput();
     QRegularExpression percentage_pattern("^%\\d\\d*\\.\\d\\d.*$");
     if (percentage_pattern.match(s).hasMatch()) {
         int percent = round(s.mid(1,5).toFloat());
         emit progress(percent);
     }
-    output += s;
-    if (console != nullptr) {
-        console->insertPlainText(s);
-        console->moveCursor(QTextCursor::End);
+    a_output += s;
+    if (a_console != nullptr) {
+        a_console->insertPlainText(s);
+        a_console->moveCursor(QTextCursor::End);
     }
 }
 
@@ -574,24 +602,43 @@ void Ngspice::slotProcessOutput()
  * \brief Ngspice::SaveNetlist Create netlist and save it to file without execution
  *        of simulator.
  * \param[in] filename Absolute path to netlist
+ * \param[in] netlist2Console Whether netlist to console instead to file
  */
-void Ngspice::SaveNetlist(QString filename)
+void Ngspice::SaveNetlist(QString filename, bool netlist2Console)
 {
-    int num=0;
-    sims.clear();
-    vars.clear();
+    a_sims.clear();
+    a_vars.clear();
 
-    QFile spice_file(filename);
-    if (spice_file.open(QFile::WriteOnly)) {
-        QTextStream stream(&spice_file);
-        createNetlist(stream,num,sims,vars,output_files);
-        spice_file.close();
+    QScopedPointer<QString> netlistString;
+    QScopedPointer<QTextStream> netlistStream;
+    QScopedPointer<QFile> netlistFile;
+
+    if (netlist2Console)
+    {
+        netlistString.reset(new QString);
+        netlistStream.reset(new QTextStream(netlistString.get()));
     }
     else
     {
-        QString msg=QString("Tried to save netlist \nin %1\n(could not open for writing!)").arg(filename);
-        QString final_msg=QString("%1\n This could be an error in the QSettings settings file\n(usually in ~/.config/qucs/qucs_s.conf)\nThe value for S4Q_workdir (default:/spice4qucs) needs to be writeable!\nFor a Simulation Simulation will raise error! (most likely S4Q_workdir does not exists)").arg(msg);
-        QMessageBox::critical(nullptr,tr("Problem with SaveNetlist"),final_msg,QMessageBox::Ok);
+        netlistFile.reset(new QFile(filename));
+        if (netlistFile->open(QFile::WriteOnly))
+        {
+            netlistStream.reset(new QTextStream(netlistFile.get()));
+        }
+        else
+        {
+            QString msg = QStringLiteral("Tried to save netlist \nin %1\n(could not open for writing!)").arg(filename);
+            QString final_msg = QStringLiteral("%1\n This could be an error in the QSettings settings file\n(usually in ~/.config/qucs/qucs_s.conf)\nThe value for S4Q_workdir (default:/spice4qucs) needs to be writeable!\nFor a Simulation Simulation will raise error! (most likely S4Q_workdir does not exists)").arg(msg);
+            QMessageBox::critical(nullptr,tr("Problem with SaveNetlist"), final_msg, QMessageBox::Ok);
+            return;
+        }
+    }
+
+    createNetlist(*netlistStream, a_sims, a_vars, a_output_files);
+
+    if (netlist2Console)
+    {
+        std::cout << netlistString->toUtf8().constData() << std::endl;
     }
 }
 
@@ -602,36 +649,52 @@ void Ngspice::setSimulatorCmd(QString cmd)
         QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
         env.remove("LANG");
         env.insert("LANG","en_US");
-        SimProcess->setProcessEnvironment(env);
-        simulator_parameters = simulator_parameters + "-c";
+        a_simProcess->setProcessEnvironment(env);
+        a_simulator_parameters = a_simulator_parameters + "-c";
     } else { // restore system environment
         QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
-        SimProcess->setProcessEnvironment(env);
+        a_simProcess->setProcessEnvironment(env);
     }
 
-    simulator_cmd = cmd;
+    a_simulator_cmd = cmd;
 }
 
 void Ngspice::setSimulatorParameters(QString parameters)
 {
-    simulator_parameters = parameters;
+    a_simulator_parameters = parameters;
 }
 
 void Ngspice::cleanSpiceinit()
 {
-    QFileInfo inf(spinit_name);
-    if (inf.exists()) QFile::remove(spinit_name);
+    QFileInfo inf(a_spinit_name);
+    if (inf.exists()) QFile::remove(a_spinit_name);
 }
 
 void Ngspice::createSpiceinit(const QString &initial_spiceinit)
 {
-    if (initial_spiceinit.isEmpty()) return;
-    QFile spinit(spinit_name);
-    if (spinit.open(QIODevice::WriteOnly)) {
-        QTextStream stream(&spinit);
-        if (!initial_spiceinit.isEmpty()) {
-          stream << initial_spiceinit << '\n';
-        }
-        spinit.close();
-    }
+  auto compat_mode = _settings::Get().item<int>("NgspiceCompatMode");
+  QString compat_str;
+  switch(compat_mode) {
+  case spicecompat::NgspLTspice:
+    compat_str = "set ngbehavior=ltpsa\n";
+    break;
+  case spicecompat::NgspHSPICE:
+    compat_str = "set ngbehavior=hsa\n";
+    break;
+  case spicecompat::NgspS3:
+    compat_str = "set ngbehavior=s3\n";
+    break;
+  default: break;
+  }
+  if (initial_spiceinit.isEmpty() &&
+      compat_str.isEmpty()) {
+    return;
+  }
+  QFile spinit(a_spinit_name);
+  if (spinit.open(QIODevice::WriteOnly)) {
+    QTextStream stream(&spinit);
+    stream << compat_str << '\n';
+    stream << initial_spiceinit << '\n';
+    spinit.close();
+  }
 }
