@@ -125,7 +125,7 @@ QString qucs2spice::convert_netlist(QString netlist, bool xyce)
 QString qucs2spice::convert_rcl(const QString& line)
 {
     QString s="";
-    QStringList lst = line.split(" ",qucs::SkipEmptyParts);
+    QStringList lst = line.split(" ", Qt::SkipEmptyParts);
     QString s1 = lst.takeFirst();
     s += s1.remove(':');
     s += " " + lst.takeFirst();
@@ -141,7 +141,7 @@ QString qucs2spice::convert_header(QString line)
 {
     QString s = line;
     s.replace(".Def:",".SUBCKT ");
-    QStringList lst = s.split(' ',qucs::SkipEmptyParts);
+    QStringList lst = s.split(' ', Qt::SkipEmptyParts);
     lst.insert(2," gnd "); // ground
     s = lst.join(" ");
     s += "\n";
@@ -151,24 +151,23 @@ QString qucs2spice::convert_header(QString line)
 QString qucs2spice::convert_diode(QString line,bool xyce)
 {
     QString s="";
-    QStringList lst = line.split(" ",qucs::SkipEmptyParts);
+    QStringList lst = line.split(" ", Qt::SkipEmptyParts);
     QString name = lst.takeFirst();
     auto idx = name.indexOf(':');
     name =  name.right(name.size()-idx-1); // name
     QString K = lst.takeFirst();
     QString A = lst.takeFirst();
-    s += QString("D%1 %2 %3 DMOD_%4 \n").arg(name).arg(A).arg(K).arg(name);
+    s += QStringLiteral("D%1 %2 %3 DMOD_%4 \n").arg(name).arg(A).arg(K).arg(name);
     QString mod_params = lst.join(" ");
     mod_params.remove('\"');
-    if (xyce) s += QString(".MODEL DMOD_%1 D(LEVEL=2 %2) \n").arg(name).arg(mod_params);
-    else  s += QString(".MODEL DMOD_%1 D(%2) \n").arg(name).arg(mod_params);
+    s += QStringLiteral(".MODEL DMOD_%1 D(%2) \n").arg(name).arg(mod_params);
     return s;
 }
 
 QString qucs2spice::convert_mosfet(QString line, bool xyce)
 {
     QString s="";
-    QStringList lst = line.split(" ",qucs::SkipEmptyParts);
+    QStringList lst = line.split(" ", Qt::SkipEmptyParts);
     QString name = lst.takeFirst();
     auto idx = name.indexOf(':');
     name =  name.right(name.size()-idx-1); // name
@@ -198,11 +197,11 @@ QString qucs2spice::convert_mosfet(QString line, bool xyce)
             par_lst.append(s1); // usual parameter
         }
     }
-    s += QString("M%1 %2 %3 %4 %5 MMOD_%6 %7 %8 \n").arg(name).arg(D).arg(G).arg(S).arg(Sub)
+    s += QStringLiteral("M%1 %2 %3 %4 %5 MMOD_%6 %7 %8 \n").arg(name).arg(D).arg(G).arg(S).arg(Sub)
             .arg(name).arg(L).arg(W);
     QString mod_params = par_lst.join(" ");
     mod_params.remove('\"');
-    s += QString(".MODEL MMOD_%1 %2(%3) \n").arg(name).arg(Typ).arg(mod_params);
+    s += QStringLiteral(".MODEL MMOD_%1 %2(%3) \n").arg(name).arg(Typ).arg(mod_params);
     if (xyce) s.replace("Vt0=","VtO=");
     return s;
 }
@@ -210,7 +209,7 @@ QString qucs2spice::convert_mosfet(QString line, bool xyce)
 QString qucs2spice::convert_jfet(const QString& line, bool xyce)
 {
     QString s="";
-    QStringList lst = line.split(" ",qucs::SkipEmptyParts);
+    QStringList lst = line.split(" ", Qt::SkipEmptyParts);
     QString name = lst.takeFirst();
     auto idx = name.indexOf(':');
     name =  name.right(name.size()-idx-1); // name
@@ -230,10 +229,10 @@ QString qucs2spice::convert_jfet(const QString& line, bool xyce)
             par_lst.append(s1); // usual parameter
         }
     }
-    s += QString("J%1 %2 %3 %4 JMOD_%5 \n").arg(name).arg(D).arg(G).arg(S).arg(name);
+    s += QStringLiteral("J%1 %2 %3 %4 JMOD_%5 \n").arg(name).arg(D).arg(G).arg(S).arg(name);
     QString mod_params = par_lst.join(" ");
     mod_params.remove('\"');
-    s += QString(".MODEL JMOD_%1 %2(%3) \n").arg(name).arg(Typ).arg(mod_params);
+    s += QStringLiteral(".MODEL JMOD_%1 %2(%3) \n").arg(name).arg(Typ).arg(mod_params);
     if (xyce) s.replace(" Vt0="," VtO=");
     return s;
 }
@@ -241,7 +240,7 @@ QString qucs2spice::convert_jfet(const QString& line, bool xyce)
 QString qucs2spice::convert_bjt(const QString& line)
 {
     QString s="";
-    QStringList lst = line.split(" ",qucs::SkipEmptyParts);
+    QStringList lst = line.split(" ", Qt::SkipEmptyParts);
     QString name = lst.takeFirst();
     auto idx = name.indexOf(':');
     name =  name.right(name.size()-idx-1); // name
@@ -272,10 +271,10 @@ QString qucs2spice::convert_bjt(const QString& line)
             if (!is_incompat) par_lst.append(s1); // usual parameter
         }
     }
-    s += QString("Q%1 %2 %3 %4 %5 QMOD_%6 \n").arg(name).arg(C).arg(B).arg(E).arg(Sub).arg(name);
+    s += QStringLiteral("Q%1 %2 %3 %4 %5 QMOD_%6 \n").arg(name).arg(C).arg(B).arg(E).arg(Sub).arg(name);
     QString mod_params = par_lst.join(" ");
     mod_params.remove('\"');
-    s += QString(".MODEL QMOD_%1 %2(%3) \n").arg(name).arg(Typ).arg(mod_params);
+    s += QStringLiteral(".MODEL QMOD_%1 %2(%3) \n").arg(name).arg(Typ).arg(mod_params);
     return s;
 }
 
@@ -291,7 +290,7 @@ QString qucs2spice::convert_ccvs(const QString& line)
 
 QString qucs2spice::convert_ccs(const QString& line, bool voltage)
 {
-    QStringList lst = line.split(" ",qucs::SkipEmptyParts);
+    QStringList lst = line.split(" ", Qt::SkipEmptyParts);
     QString name = lst.takeFirst();
     auto idx = name.indexOf(':');
     name =  name.right(name.size()-idx-1); // name
@@ -306,8 +305,8 @@ QString qucs2spice::convert_ccs(const QString& line, bool voltage)
     QString s;
     if (voltage) s="H";
     else s="F";
-    s += QString("%1 %2 %3 V%4 %5\n").arg(name).arg(nod1).arg(nod2).arg(name).arg(val); // output source nodes
-    s += QString("V%1 %2 %3 DC 0\n").arg(name).arg(nod0).arg(nod3);   // controlling 0V source
+    s += QStringLiteral("%1 %2 %3 V%4 %5\n").arg(name).arg(nod1).arg(nod2).arg(name).arg(val); // output source nodes
+    s += QStringLiteral("V%1 %2 %3 DC 0\n").arg(name).arg(nod0).arg(nod3);   // controlling 0V source
     return s;
 }
 
@@ -323,7 +322,7 @@ QString qucs2spice::convert_vcvs(const QString& line)
 
 QString qucs2spice::convert_vcs(const QString& line,bool voltage)
 {
-    QStringList lst = line.split(" ",qucs::SkipEmptyParts);
+    QStringList lst = line.split(" ", Qt::SkipEmptyParts);
     QString name = lst.takeFirst();
     auto idx = name.indexOf(':');
     name =  name.right(name.size()-idx-1); // name
@@ -339,14 +338,14 @@ QString qucs2spice::convert_vcs(const QString& line,bool voltage)
     QString s;
     if (voltage) s="E";
     else s="G";
-    s += QString("%1 %2 %3 %4 %5 %6\n").arg(name).arg(nod1).arg(nod2).arg(nod0).arg(nod3).arg(val);
+    s += QStringLiteral("%1 %2 %3 %4 %5 %6\n").arg(name).arg(nod1).arg(nod2).arg(nod0).arg(nod3).arg(val);
     return s;
 }
 
 QString qucs2spice::convert_dc_src(const QString& line)
 {
     QString s="";
-    QStringList lst = line.split(" ",qucs::SkipEmptyParts);
+    QStringList lst = line.split(" ", Qt::SkipEmptyParts);
     QString s1 = lst.takeFirst();
     s += s1.remove(':');
     s += " " + lst.takeFirst();
@@ -361,7 +360,7 @@ QString qucs2spice::convert_dc_src(const QString& line)
 QString qucs2spice::convert_edd(const QString& line, QStringList &EqnsAndVars)
 {
     QString s="";
-    QStringList lst = line.split(" ",qucs::SkipEmptyParts);
+    QStringList lst = line.split(" ", Qt::SkipEmptyParts);
     QStringList nods;
     QString nam = lst.takeFirst().remove(':');
 
@@ -386,16 +385,16 @@ QString qucs2spice::convert_edd(const QString& line, QStringList &EqnsAndVars)
         QString plus = nods.at(2*i+1);
         QString minus = nods.at(2*i);
 
-        s += QString("BI%1_%2 %3 %4 I=%5\n").arg(nam).arg(i).arg(plus).arg(minus).arg(Itokens.join(""));
+        s += QStringLiteral("BI%1_%2 %3 %4 I=%5\n").arg(nam).arg(i).arg(plus).arg(minus).arg(Itokens.join(""));
         // charge part
         QString Qvar = line.section('"',2*i+3,2*i+3,QString::SectionSkipEmpty);
         QString Qeqn = EqnsAndVars.at(EqnsAndVars.indexOf(Qvar)+1);
         Qeqn.remove(' ');
         QRegularExpression zero_pattern("0+(\\.*0+|)");
         if (!zero_pattern.match(Qeqn).hasMatch()) {
-            s += QString("G%1Q%2 %3 %4 n%1Q%2 %4 1.0\n").arg(nam).arg(i).arg(plus).arg(minus);
-            s += QString("L%1Q%2 n%1Q%2 %3 1.0\n").arg(nam).arg(i).arg(minus);
-            s += QString("B%1Q%2 n%1Q%2 %3 I=-(%4)\n").arg(nam).arg(i).arg(minus).arg(Qeqn);
+            s += QStringLiteral("G%1Q%2 %3 %4 n%1Q%2 %4 1.0\n").arg(nam).arg(i).arg(plus).arg(minus);
+            s += QStringLiteral("L%1Q%2 n%1Q%2 %3 1.0\n").arg(nam).arg(i).arg(minus);
+            s += QStringLiteral("B%1Q%2 n%1Q%2 %3 I=-(%4)\n").arg(nam).arg(i).arg(minus).arg(Qeqn);
         }
     }
 
@@ -406,7 +405,7 @@ QString qucs2spice::convert_edd(const QString& line, QStringList &EqnsAndVars)
 QString qucs2spice::convert_subckt(QString line)
 {
     QString s="";
-    QStringList lst = line.split(" ",qucs::SkipEmptyParts);
+    QStringList lst = line.split(" ", Qt::SkipEmptyParts);
     QString s1 = lst.takeFirst();
     s += "X" + s1.remove("Sub:") + " gnd ";
 
@@ -430,7 +429,7 @@ QString qucs2spice::convert_subckt(QString line)
         it++;
         QString val = (*it);
         val.remove(' ');
-        s += QString("%1=%2 ").arg(var).arg(val);
+        s += QStringLiteral("%1=%2 ").arg(var).arg(val);
     }
     s += '\n';
 
@@ -440,7 +439,7 @@ QString qucs2spice::convert_subckt(QString line)
 QString qucs2spice::convert_gyrator(QString line)
 {
     QString s="";
-    QStringList lst = line.split(" ",qucs::SkipEmptyParts);
+    QStringList lst = line.split(" ", Qt::SkipEmptyParts);
     QString Name = lst.takeFirst();
     Name = Name.section(':',1,1);
     QString n1 = lst.takeFirst();
@@ -448,8 +447,8 @@ QString qucs2spice::convert_gyrator(QString line)
     QString n3 = lst.takeFirst();
     QString n4 = lst.takeFirst();
     QString R = line.section('"',1,1);
-    s +=  QString("B%1_1 %2 %3 I=(1/(%4))*(V(%5)-V(%6))\n").arg(Name).arg(n1).arg(n4).arg(R).arg(n2).arg(n3);
-    s +=  QString("B%1_2 %2 %3 I=-1.0*(1/(%4))*(V(%5)-V(%6))\n").arg(Name).arg(n2).arg(n3).arg(R).arg(n1).arg(n4);
+    s +=  QStringLiteral("B%1_1 %2 %3 I=(1/(%4))*(V(%5)-V(%6))\n").arg(Name).arg(n1).arg(n4).arg(R).arg(n2).arg(n3);
+    s +=  QStringLiteral("B%1_2 %2 %3 I=-1.0*(1/(%4))*(V(%5)-V(%6))\n").arg(Name).arg(n2).arg(n3).arg(R).arg(n1).arg(n4);
     return s;
 }
 
@@ -489,7 +488,7 @@ void qucs2spice::subsVoltages(QStringList &tokens, QStringList& nods)
             QString minus = nods.at(2*(i-1));
             //if (plus=="gnd") plus="0";
             //if (minus=="gnd") minus="0";
-            *it = QString("(V(%1)-V(%2))").arg(plus).arg(minus);
+            *it = QStringLiteral("(V(%1)-V(%2))").arg(plus).arg(minus);
         }
     }
 }
