@@ -46,11 +46,9 @@
 #include "qpixmap.h"
 #include "qcursor.h"
 #include "q3scrollview.h"
-#include "q3ptrdict.h"
 #include "qapplication.h"
 #include "qtimer.h"
 #include "qstyle.h"
-#include "qt_compat.h"
 #include "qevent.h"
 
 using namespace Qt;
@@ -139,7 +137,7 @@ public:
     }
     ~Q3ScrollViewData();
 
-    QSVChildRec* rec(QWidget* w) { return childDict.find(w); }
+    QSVChildRec* rec(QWidget* w) { return childDict.contains(w) ? *(childDict.find(w)) : nullptr; }
     QSVChildRec* ancestorRec(QWidget* w);
     QSVChildRec* addChildRec(QWidget* w, int x, int y)
     {
@@ -151,7 +149,7 @@ public:
     void deleteChildRec(QSVChildRec* r)
     {
         childDict.remove(r->child);
-        children.removeRef(r);
+        children.removeOne(r);
         delete r;
     }
 
@@ -170,8 +168,8 @@ public:
     QAbstractScrollAreaWidget*    viewport;
     QClipperWidget*     clipped_viewport;
     int         flags;
-    Q3PtrList<QSVChildRec>       children;
-    Q3PtrDict<QSVChildRec>       childDict;
+    QList<QSVChildRec*>       children;
+    QMap<QWidget*,QSVChildRec*>       childDict;
     QWidget*    corner;
     int         vx, vy, vwidth, vheight; // for drawContents-style usage
     int         l_marg, r_marg, t_marg, b_marg;
@@ -209,7 +207,8 @@ public:
 
 inline Q3ScrollViewData::~Q3ScrollViewData()
 {
-    children.setAutoDelete(true);
+    qDeleteAll(children);
+    children.clear();
 }
 
 QSVChildRec* Q3ScrollViewData::ancestorRec(QWidget* w)
@@ -250,7 +249,7 @@ void Q3ScrollViewData::hideOrShowAll(Q3ScrollView* sv, bool isScroll)
         clipped_viewport->move(nx,ny);
         clipped_viewport->update();
     }
-    for (QSVChildRec *r = children.first(); r; r=children.next()) {
+    for (QSVChildRec *r : children) {
         r->hideOrShow(sv, clipped_viewport);
     }
 }
@@ -261,7 +260,7 @@ void Q3ScrollViewData::moveAllBy(int dx, int dy)
         clipped_viewport->move(clipped_viewport->x()+dx,
                                 clipped_viewport->y()+dy);
     } else {
-        for (QSVChildRec *r = children.first(); r; r=children.next()) {
+        for (QSVChildRec *r : children) {
             r->child->move(r->child->x()+dx,r->child->y()+dy);
         }
         if (static_bg)
@@ -271,7 +270,7 @@ void Q3ScrollViewData::moveAllBy(int dx, int dy)
 
 bool Q3ScrollViewData::anyVisibleChildren()
 {
-    for (QSVChildRec *r = children.first(); r; r=children.next()) {
+    for (QSVChildRec *r : children) {
         if (r->child->isVisible()) return true;
     }
     return false;
