@@ -18,10 +18,10 @@
 #ifndef SP_NOISE_H
 #define SP_NOISE_H
 
-#include "components/component.h"
+#include "components/simulation.h"
 
 
-class SpiceNoise : public Component  {
+class SpiceNoise : public qucs::component::SimulationComponent {
 public:
   SpiceNoise();
   ~SpiceNoise();
@@ -29,7 +29,7 @@ public:
   static Element* info(QString&, char* &, bool getNewOne=false);
 
 protected:
-  QString spice_netlist(bool isXyce = false);
+  QString spice_netlist(spicecompat::SpiceDialect dialect = spicecompat::SPICEDefault);
 };
 
 #endif
